==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/EwidencjaDps.java <==
package pl.topteam.dps.model.main_gen;

import java.util.Date;
import pl.topteam.dps.enums.NumerProfilu;
import pl.topteam.dps.enums.TypEwidencji;
import pl.topteam.dps.generic.GenericDPSObject;

public abstract class EwidencjaDps extends GenericDPSObject {
    /**
     * EWIDENCJA_DPS.ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long id;

    /**
     * EWIDENCJA_DPS.EWID_POPRZEDNI_WPIS_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long ewidPoprzedniWpisId;

    /**
     * EWIDENCJA_DPS.DOKAD_ODSZEDL_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long dokadOdszedlId;

    /**
     * EWIDENCJA_DPS.OSOBA_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long osobaId;

    /**
     * EWIDENCJA_DPS.SZABLON_WYDRUKU_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long szablonWydrukuId;

    /**
     * EWIDENCJA_DPS.DATA_OD
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Date dataOd;

    /**
     * EWIDENCJA_DPS.DATA_DO
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Date dataDo;

    /**
     * EWIDENCJA_DPS.NUMER_EWIDENCYJNY
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private String numerEwidencyjny;

    /**
     * EWIDENCJA_DPS.STALE_ZAMELDOWANIE_DOM
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Boolean staleZameldowanieDom;

    /**
     * EWIDENCJA_DPS.TYP
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private TypEwidencji typ;

    /**
     * EWIDENCJA_DPS.PROFIL_DOMU
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private NumerProfilu profilDomu;

    /**
     * EWIDENCJA_DPS.SKAD_PRZYSZEDL_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long skadPrzyszedlId;

    /**
     * EWIDENCJA_DPS.DZIEN_PIERWSZY_ODPLATNY
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Boolean dzienPierwszyOdplatny;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return EWIDENCJA_DPS.ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * EWIDENCJA_DPS.ID
     *
     * @param id
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return EWIDENCJA_DPS.EWID_POPRZEDNI_WPIS_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getEwidPoprzedniWpisId() {
        return ewidPoprzedniWpisId;
    }

    /**
     * EWIDENCJA_DPS.EWID_POPRZEDNI_WPIS_ID
     *
     * @param ewidPoprzedniWpisId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setEwidPoprzedniWpisId(Long ewidPoprzedniWpisId) {
        this.ewidPoprzedniWpisId = ewidPoprzedniWpisId;
    }

    /**
     * @return EWIDENCJA_DPS.DOKAD_ODSZEDL_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getDokadOdszedlId() {
        return dokadOdszedlId;
    }

    /**
     * EWIDENCJA_DPS.DOKAD_ODSZEDL_ID
     *
     * @param dokadOdszedlId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setDokadOdszedlId(Long dokadOdszedlId) {
        this.dokadOdszedlId = dokadOdszedlId;
    }

    /**
     * @return EWIDENCJA_DPS.OSOBA_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getOsobaId() {
        return osobaId;
    }

    /**
     * EWIDENCJA_DPS.OSOBA_ID
     *
     * @param osobaId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setOsobaId(Long osobaId) {
        this.osobaId = osobaId;
    }

    /**
     * @return EWIDENCJA_DPS.SZABLON_WYDRUKU_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getSzablonWydrukuId() {
        return szablonWydrukuId;
    }

    /**
     * EWIDENCJA_DPS.SZABLON_WYDRUKU_ID
     *
     * @param szablonWydrukuId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setSzablonWydrukuId(Long szablonWydrukuId) {
        this.szablonWydrukuId = szablonWydrukuId;
    }

    /**
     * @return EWIDENCJA_DPS.DATA_OD
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Date getDataOd() {
        return dataOd;
    }

    /**
     * EWIDENCJA_DPS.DATA_OD
     *
     * @param dataOd
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setDataOd(Date dataOd) {
        this.dataOd = dataOd;
    }

    /**
     * @return EWIDENCJA_DPS.DATA_DO
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Date getDataDo() {
        return dataDo;
    }

    /**
     * EWIDENCJA_DPS.DATA_DO
     *
     * @param dataDo
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setDataDo(Date dataDo) {
        this.dataDo = dataDo;
    }

    /**
     * @return EWIDENCJA_DPS.NUMER_EWIDENCYJNY
     * @mbggenerated 2014-03-10 10:45:37
     */
    public String getNumerEwidencyjny() {
        return numerEwidencyjny;
    }

    /**
     * EWIDENCJA_DPS.NUMER_EWIDENCYJNY
     *
     * @param numerEwidencyjny
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setNumerEwidencyjny(String numerEwidencyjny) {
        this.numerEwidencyjny = numerEwidencyjny == null ? null : numerEwidencyjny.trim();
    }

    /**
     * @return EWIDENCJA_DPS.STALE_ZAMELDOWANIE_DOM
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Boolean getStaleZameldowanieDom() {
        return staleZameldowanieDom;
    }

    /**
     * EWIDENCJA_DPS.STALE_ZAMELDOWANIE_DOM
     *
     * @param staleZameldowanieDom
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setStaleZameldowanieDom(Boolean staleZameldowanieDom) {
        this.staleZameldowanieDom = staleZameldowanieDom;
    }

    /**
     * @return EWIDENCJA_DPS.TYP
     * @mbggenerated 2014-03-10 10:45:37
     */
    public TypEwidencji getTyp() {
        return typ;
    }

    /**
     * EWIDENCJA_DPS.TYP
     *
     * @param typ
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setTyp(TypEwidencji typ) {
        this.typ = typ;
    }

    /**
     * @return EWIDENCJA_DPS.PROFIL_DOMU
     * @mbggenerated 2014-03-10 10:45:37
     */
    public NumerProfilu getProfilDomu() {
        return profilDomu;
    }

    /**
     * EWIDENCJA_DPS.PROFIL_DOMU
     *
     * @param profilDomu
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setProfilDomu(NumerProfilu profilDomu) {
        this.profilDomu = profilDomu;
    }

    /**
     * @return EWIDENCJA_DPS.SKAD_PRZYSZEDL_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getSkadPrzyszedlId() {
        return skadPrzyszedlId;
    }

    /**
     * EWIDENCJA_DPS.SKAD_PRZYSZEDL_ID
     *
     * @param skadPrzyszedlId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setSkadPrzyszedlId(Long skadPrzyszedlId) {
        this.skadPrzyszedlId = skadPrzyszedlId;
    }

    /**
     * @return EWIDENCJA_DPS.DZIEN_PIERWSZY_ODPLATNY
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Boolean getDzienPierwszyOdplatny() {
        return dzienPierwszyOdplatny;
    }

    /**
     * EWIDENCJA_DPS.DZIEN_PIERWSZY_ODPLATNY
     *
     * @param dzienPierwszyOdplatny
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setDzienPierwszyOdplatny(Boolean dzienPierwszyOdplatny) {
        this.dzienPierwszyOdplatny = dzienPierwszyOdplatny;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        EwidencjaDps other = (EwidencjaDps) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getEwidPoprzedniWpisId() == null ? other.getEwidPoprzedniWpisId() == null : this.getEwidPoprzedniWpisId().equals(other.getEwidPoprzedniWpisId()))
            && (this.getDokadOdszedlId() == null ? other.getDokadOdszedlId() == null : this.getDokadOdszedlId().equals(other.getDokadOdszedlId()))
            && (this.getOsobaId() == null ? other.getOsobaId() == null : this.getOsobaId().equals(other.getOsobaId()))
            && (this.getSzablonWydrukuId() == null ? other.getSzablonWydrukuId() == null : this.getSzablonWydrukuId().equals(other.getSzablonWydrukuId()))
            && (this.getDataOd() == null ? other.getDataOd() == null : this.getDataOd().equals(other.getDataOd()))
            && (this.getDataDo() == null ? other.getDataDo() == null : this.getDataDo().equals(other.getDataDo()))
            && (this.getNumerEwidencyjny() == null ? other.getNumerEwidencyjny() == null : this.getNumerEwidencyjny().equals(other.getNumerEwidencyjny()))
            && (this.getStaleZameldowanieDom() == null ? other.getStaleZameldowanieDom() == null : this.getStaleZameldowanieDom().equals(other.getStaleZameldowanieDom()))
            && (this.getTyp() == null ? other.getTyp() == null : this.getTyp().equals(other.getTyp()))
            && (this.getProfilDomu() == null ? other.getProfilDomu() == null : this.getProfilDomu().equals(other.getProfilDomu()))
            && (this.getSkadPrzyszedlId() == null ? other.getSkadPrzyszedlId() == null : this.getSkadPrzyszedlId().equals(other.getSkadPrzyszedlId()))
            && (this.getDzienPierwszyOdplatny() == null ? other.getDzienPierwszyOdplatny() == null : this.getDzienPierwszyOdplatny().equals(other.getDzienPierwszyOdplatny()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getEwidPoprzedniWpisId() == null) ? 0 : getEwidPoprzedniWpisId().hashCode());
        result = prime * result + ((getDokadOdszedlId() == null) ? 0 : getDokadOdszedlId().hashCode());
        result = prime * result + ((getOsobaId() == null) ? 0 : getOsobaId().hashCode());
        result = prime * result + ((getSzablonWydrukuId() == null) ? 0 : getSzablonWydrukuId().hashCode());
        result = prime * result + ((getDataOd() == null) ? 0 : getDataOd().hashCode());
        result = prime * result + ((getDataDo() == null) ? 0 : getDataDo().hashCode());
        result = prime * result + ((getNumerEwidencyjny() == null) ? 0 : getNumerEwidencyjny().hashCode());
        result = prime * result + ((getStaleZameldowanieDom() == null) ? 0 : getStaleZameldowanieDom().hashCode());
        result = prime * result + ((getTyp() == null) ? 0 : getTyp().hashCode());
        result = prime * result + ((getProfilDomu() == null) ? 0 : getProfilDomu().hashCode());
        result = prime * result + ((getSkadPrzyszedlId() == null) ? 0 : getSkadPrzyszedlId().hashCode());
        result = prime * result + ((getDzienPierwszyOdplatny() == null) ? 0 : getDzienPierwszyOdplatny().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", ewidPoprzedniWpisId=").append(ewidPoprzedniWpisId);
        sb.append(", dokadOdszedlId=").append(dokadOdszedlId);
        sb.append(", osobaId=").append(osobaId);
        sb.append(", szablonWydrukuId=").append(szablonWydrukuId);
        sb.append(", dataOd=").append(dataOd);
        sb.append(", dataDo=").append(dataDo);
        sb.append(", numerEwidencyjny=").append(numerEwidencyjny);
        sb.append(", staleZameldowanieDom=").append(staleZameldowanieDom);
        sb.append(", typ=").append(typ);
        sb.append(", profilDomu=").append(profilDomu);
        sb.append(", skadPrzyszedlId=").append(skadPrzyszedlId);
        sb.append(", dzienPierwszyOdplatny=").append(dzienPierwszyOdplatny);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/EwidencjaDps.java <==
package pl.topteam.dps.model.main_gen;

import java.util.Date;
import pl.topteam.dps.enums.NumerProfilu;
import pl.topteam.dps.enums.TypEwidencji;
import pl.topteam.dps.model.main_gen.GenericDPSObject;

public abstract class EwidencjaDps extends GenericDPSObject {
    /**
     * EWIDENCJA_DPS.ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long id;

    /**
     * EWIDENCJA_DPS.EWID_POPRZEDNI_WPIS_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long ewidPoprzedniWpisId;

    /**
     * EWIDENCJA_DPS.DOKAD_ODSZEDL_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long dokadOdszedlId;

    /**
     * EWIDENCJA_DPS.OSOBA_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long osobaId;

    /**
     * EWIDENCJA_DPS.SZABLON_WYDRUKU_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long szablonWydrukuId;

    /**
     * EWIDENCJA_DPS.DATA_OD
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Date dataOd;

    /**
     * EWIDENCJA_DPS.DATA_DO
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Date dataDo;

    /**
     * EWIDENCJA_DPS.NUMER_EWIDENCYJNY
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private String numerEwidencyjny;

    /**
     * EWIDENCJA_DPS.STALE_ZAMELDOWANIE_DOM
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Boolean staleZameldowanieDom;

    /**
     * EWIDENCJA_DPS.TYP
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private TypEwidencji typ;

    /**
     * EWIDENCJA_DPS.PROFIL_DOMU
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private NumerProfilu profilDomu;

    /**
     * EWIDENCJA_DPS.SKAD_PRZYSZEDL_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long skadPrzyszedlId;

    /**
     * EWIDENCJA_DPS.DZIEN_PIERWSZY_ODPLATNY
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Boolean dzienPierwszyOdplatny;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return EWIDENCJA_DPS.ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * EWIDENCJA_DPS.ID
     *
     * @param id
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return EWIDENCJA_DPS.EWID_POPRZEDNI_WPIS_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getEwidPoprzedniWpisId() {
        return ewidPoprzedniWpisId;
    }

    /**
     * EWIDENCJA_DPS.EWID_POPRZEDNI_WPIS_ID
     *
     * @param ewidPoprzedniWpisId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setEwidPoprzedniWpisId(Long ewidPoprzedniWpisId) {
        this.ewidPoprzedniWpisId = ewidPoprzedniWpisId;
    }

    /**
     * @return EWIDENCJA_DPS.DOKAD_ODSZEDL_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getDokadOdszedlId() {
        return dokadOdszedlId;
    }

    /**
     * EWIDENCJA_DPS.DOKAD_ODSZEDL_ID
     *
     * @param dokadOdszedlId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setDokadOdszedlId(Long dokadOdszedlId) {
        this.dokadOdszedlId = dokadOdszedlId;
    }

    /**
     * @return EWIDENCJA_DPS.OSOBA_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getOsobaId() {
        return osobaId;
    }

    /**
     * EWIDENCJA_DPS.OSOBA_ID
     *
     * @param osobaId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setOsobaId(Long osobaId) {
        this.osobaId = osobaId;
    }

    /**
     * @return EWIDENCJA_DPS.SZABLON_WYDRUKU_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getSzablonWydrukuId() {
        return szablonWydrukuId;
    }

    /**
     * EWIDENCJA_DPS.SZABLON_WYDRUKU_ID
     *
     * @param szablonWydrukuId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setSzablonWydrukuId(Long szablonWydrukuId) {
        this.szablonWydrukuId = szablonWydrukuId;
    }

    /**
     * @return EWIDENCJA_DPS.DATA_OD
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Date getDataOd() {
        return dataOd;
    }

    /**
     * EWIDENCJA_DPS.DATA_OD
     *
     * @param dataOd
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setDataOd(Date dataOd) {
        this.dataOd = dataOd;
    }

    /**
     * @return EWIDENCJA_DPS.DATA_DO
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Date getDataDo() {
        return dataDo;
    }

    /**
     * EWIDENCJA_DPS.DATA_DO
     *
     * @param dataDo
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setDataDo(Date dataDo) {
        this.dataDo = dataDo;
    }

    /**
     * @return EWIDENCJA_DPS.NUMER_EWIDENCYJNY
     * @mbggenerated 2014-03-13 16:02:38
     */
    public String getNumerEwidencyjny() {
        return numerEwidencyjny;
    }

    /**
     * EWIDENCJA_DPS.NUMER_EWIDENCYJNY
     *
     * @param numerEwidencyjny
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setNumerEwidencyjny(String numerEwidencyjny) {
        this.numerEwidencyjny = numerEwidencyjny == null ? null : numerEwidencyjny.trim();
    }

    /**
     * @return EWIDENCJA_DPS.STALE_ZAMELDOWANIE_DOM
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Boolean getStaleZameldowanieDom() {
        return staleZameldowanieDom;
    }

    /**
     * EWIDENCJA_DPS.STALE_ZAMELDOWANIE_DOM
     *
     * @param staleZameldowanieDom
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setStaleZameldowanieDom(Boolean staleZameldowanieDom) {
        this.staleZameldowanieDom = staleZameldowanieDom;
    }

    /**
     * @return EWIDENCJA_DPS.TYP
     * @mbggenerated 2014-03-13 16:02:38
     */
    public TypEwidencji getTyp() {
        return typ;
    }

    /**
     * EWIDENCJA_DPS.TYP
     *
     * @param typ
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setTyp(TypEwidencji typ) {
        this.typ = typ;
    }

    /**
     * @return EWIDENCJA_DPS.PROFIL_DOMU
     * @mbggenerated 2014-03-13 16:02:38
     */
    public NumerProfilu getProfilDomu() {
        return profilDomu;
    }

    /**
     * EWIDENCJA_DPS.PROFIL_DOMU
     *
     * @param profilDomu
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setProfilDomu(NumerProfilu profilDomu) {
        this.profilDomu = profilDomu;
    }

    /**
     * @return EWIDENCJA_DPS.SKAD_PRZYSZEDL_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getSkadPrzyszedlId() {
        return skadPrzyszedlId;
    }

    /**
     * EWIDENCJA_DPS.SKAD_PRZYSZEDL_ID
     *
     * @param skadPrzyszedlId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setSkadPrzyszedlId(Long skadPrzyszedlId) {
        this.skadPrzyszedlId = skadPrzyszedlId;
    }

    /**
     * @return EWIDENCJA_DPS.DZIEN_PIERWSZY_ODPLATNY
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Boolean getDzienPierwszyOdplatny() {
        return dzienPierwszyOdplatny;
    }

    /**
     * EWIDENCJA_DPS.DZIEN_PIERWSZY_ODPLATNY
     *
     * @param dzienPierwszyOdplatny
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setDzienPierwszyOdplatny(Boolean dzienPierwszyOdplatny) {
        this.dzienPierwszyOdplatny = dzienPierwszyOdplatny;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        EwidencjaDps other = (EwidencjaDps) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getEwidPoprzedniWpisId() == null ? other.getEwidPoprzedniWpisId() == null : this.getEwidPoprzedniWpisId().equals(other.getEwidPoprzedniWpisId()))
            && (this.getDokadOdszedlId() == null ? other.getDokadOdszedlId() == null : this.getDokadOdszedlId().equals(other.getDokadOdszedlId()))
            && (this.getOsobaId() == null ? other.getOsobaId() == null : this.getOsobaId().equals(other.getOsobaId()))
            && (this.getSzablonWydrukuId() == null ? other.getSzablonWydrukuId() == null : this.getSzablonWydrukuId().equals(other.getSzablonWydrukuId()))
            && (this.getDataOd() == null ? other.getDataOd() == null : this.getDataOd().equals(other.getDataOd()))
            && (this.getDataDo() == null ? other.getDataDo() == null : this.getDataDo().equals(other.getDataDo()))
            && (this.getNumerEwidencyjny() == null ? other.getNumerEwidencyjny() == null : this.getNumerEwidencyjny().equals(other.getNumerEwidencyjny()))
            && (this.getStaleZameldowanieDom() == null ? other.getStaleZameldowanieDom() == null : this.getStaleZameldowanieDom().equals(other.getStaleZameldowanieDom()))
            && (this.getTyp() == null ? other.getTyp() == null : this.getTyp().equals(other.getTyp()))
            && (this.getProfilDomu() == null ? other.getProfilDomu() == null : this.getProfilDomu().equals(other.getProfilDomu()))
            && (this.getSkadPrzyszedlId() == null ? other.getSkadPrzyszedlId() == null : this.getSkadPrzyszedlId().equals(other.getSkadPrzyszedlId()))
            && (this.getDzienPierwszyOdplatny() == null ? other.getDzienPierwszyOdplatny() == null : this.getDzienPierwszyOdplatny().equals(other.getDzienPierwszyOdplatny()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getEwidPoprzedniWpisId() == null) ? 0 : getEwidPoprzedniWpisId().hashCode());
        result = prime * result + ((getDokadOdszedlId() == null) ? 0 : getDokadOdszedlId().hashCode());
        result = prime * result + ((getOsobaId() == null) ? 0 : getOsobaId().hashCode());
        result = prime * result + ((getSzablonWydrukuId() == null) ? 0 : getSzablonWydrukuId().hashCode());
        result = prime * result + ((getDataOd() == null) ? 0 : getDataOd().hashCode());
        result = prime * result + ((getDataDo() == null) ? 0 : getDataDo().hashCode());
        result = prime * result + ((getNumerEwidencyjny() == null) ? 0 : getNumerEwidencyjny().hashCode());
        result = prime * result + ((getStaleZameldowanieDom() == null) ? 0 : getStaleZameldowanieDom().hashCode());
        result = prime * result + ((getTyp() == null) ? 0 : getTyp().hashCode());
        result = prime * result + ((getProfilDomu() == null) ? 0 : getProfilDomu().hashCode());
        result = prime * result + ((getSkadPrzyszedlId() == null) ? 0 : getSkadPrzyszedlId().hashCode());
        result = prime * result + ((getDzienPierwszyOdplatny() == null) ? 0 : getDzienPierwszyOdplatny().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", ewidPoprzedniWpisId=").append(ewidPoprzedniWpisId);
        sb.append(", dokadOdszedlId=").append(dokadOdszedlId);
        sb.append(", osobaId=").append(osobaId);
        sb.append(", szablonWydrukuId=").append(szablonWydrukuId);
        sb.append(", dataOd=").append(dataOd);
        sb.append(", dataDo=").append(dataDo);
        sb.append(", numerEwidencyjny=").append(numerEwidencyjny);
        sb.append(", staleZameldowanieDom=").append(staleZameldowanieDom);
        sb.append(", typ=").append(typ);
        sb.append(", profilDomu=").append(profilDomu);
        sb.append(", skadPrzyszedlId=").append(skadPrzyszedlId);
        sb.append(", dzienPierwszyOdplatny=").append(dzienPierwszyOdplatny);
        sb.append("]");
        return sb.toString();
    }
}
